@@ -27,7 +27,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include <libgames-support/games-conf.h>
 #include <libgames-support/games-frame.h>
 #include <libgames-support/games-files.h>
 #include <libgames-support/games-sound.h>
@@ -38,18 +37,16 @@
 #include "othello.h"
 
 #define KEY_TILESET             "tileset"
-#define KEY_BLACK_LEVEL         "black_level"
-#define KEY_WHITE_LEVEL         "white_level"
-#define KEY_QUICK_MOVES         "quick_moves"
+#define KEY_BLACK_LEVEL         "black-level"
+#define KEY_WHITE_LEVEL         "white-level"
+#define KEY_QUICK_MOVES         "quick-moves"
 #define KEY_ANIMATE             "animate"
-#define KEY_ANIMATE_STAGGER     "animate_stagger"
-#define KEY_SHOW_GRID           "show_grid"
-#define KEY_FLIP_FINAL_RESULTS "flip_final_results"
+#define KEY_ANIMATE_STAGGER     "animate-stagger"
+#define KEY_SHOW_GRID           "show-grid"
+#define KEY_FLIP_FINAL_RESULTS "flip-final-results"
 #define KEY_SOUND               "sound"
 
-#define DEFAULT_TILESET "classic.png"
-
-
+extern GSettings *settings;
 extern GtkWidget *window;
 extern guint black_computer_level;
 extern guint white_computer_level;
@@ -61,9 +58,8 @@ extern gchar *tile_set_tmp;
 extern gint8 pixmaps[8][8];
 extern gint animate;
 extern gint animate_stagger;
-extern gint flip_pixmaps_id;
 extern gint flip_final;
-extern gint grid;
+gint show_grid;
 gint sound;
 
 guint t_black_computer_level;
@@ -83,27 +79,14 @@ static void apply_changes (void);
  *	It doesn't abide by the HIG.
  */
 
-static gint
-clamp_int (gint input, gint low, gint high)
-{
-  if (input < low)
-    input = low;
-  if (input > high)
-    input = high;
-
-  return input;
-}
-
 void
 load_properties (void)
 {
-  black_computer_level = games_conf_get_integer (NULL, KEY_BLACK_LEVEL, NULL);
-  black_computer_level = clamp_int (black_computer_level, 0, 3);
+  black_computer_level = g_settings_get_int (settings, KEY_BLACK_LEVEL);
 
-  white_computer_level = games_conf_get_integer (NULL, KEY_WHITE_LEVEL, NULL);
-  white_computer_level = clamp_int (white_computer_level, 0, 3);
+  white_computer_level = g_settings_get_int (settings, KEY_WHITE_LEVEL);
 
-  if (games_conf_get_boolean (NULL, KEY_QUICK_MOVES, NULL))
+  if (g_settings_get_boolean (settings, KEY_QUICK_MOVES))
     computer_speed = COMPUTER_MOVE_DELAY / 2;
   else
     computer_speed = COMPUTER_MOVE_DELAY;
@@ -111,31 +94,29 @@ load_properties (void)
   if (tile_set)
     g_free (tile_set);
 
-  tile_set = games_conf_get_string_with_default (NULL, KEY_TILESET, DEFAULT_TILESET);
+  tile_set = g_settings_get_string (settings, KEY_TILESET);
 
-  animate = games_conf_get_integer (NULL, KEY_ANIMATE, NULL);
-  animate = clamp_int (animate, 0, 2);
+  animate = g_settings_get_int (settings, KEY_ANIMATE);
 
-  animate_stagger = games_conf_get_boolean (NULL, KEY_ANIMATE_STAGGER, NULL);
+  animate_stagger = g_settings_get_boolean (settings, KEY_ANIMATE_STAGGER);
 
-  sound = games_conf_get_boolean (NULL, KEY_SOUND, NULL);
+  sound = g_settings_get_boolean (settings, KEY_SOUND);
   games_sound_enable (sound);
 
-  grid = games_conf_get_boolean (NULL, KEY_SHOW_GRID, NULL);
+  show_grid = g_settings_get_boolean (settings, KEY_SHOW_GRID);
 
-  flip_final = games_conf_get_boolean (NULL, KEY_FLIP_FINAL_RESULTS, NULL);
+  flip_final = g_settings_get_boolean (settings, KEY_FLIP_FINAL_RESULTS);
 
   switch (animate) {
   case 0:
-    flip_pixmaps_id = g_timeout_add (100, flip_pixmaps, NULL);
+    set_animation_speed (100);
     break;
   case 1:
-    flip_pixmaps_id =
-      g_timeout_add (PIXMAP_FLIP_DELAY * 8, flip_pixmaps, NULL);
+    set_animation_speed (PIXMAP_FLIP_DELAY * 8);
     break;
   default:
   case 2:
-    flip_pixmaps_id = g_timeout_add (PIXMAP_FLIP_DELAY, flip_pixmaps, NULL);
+    set_animation_speed (PIXMAP_FLIP_DELAY);
     break;
   }
 }
@@ -143,25 +124,23 @@ load_properties (void)
 static void
 reset_properties (void)
 {
-  black_computer_level = games_conf_get_integer (NULL, KEY_BLACK_LEVEL, NULL);
-  black_computer_level = clamp_int (black_computer_level, 0, 3);
+  black_computer_level = g_settings_get_int (settings, KEY_BLACK_LEVEL);
 
-  white_computer_level = games_conf_get_integer (NULL, KEY_WHITE_LEVEL, NULL);
-  white_computer_level = clamp_int (white_computer_level, 0, 3);
+  white_computer_level = g_settings_get_int (settings, KEY_WHITE_LEVEL);
       
   t_black_computer_level = black_computer_level;
   t_white_computer_level = white_computer_level;
 
-  t_quick_moves = games_conf_get_boolean (NULL, KEY_QUICK_MOVES, NULL);
+  t_quick_moves = g_settings_get_boolean (settings, KEY_QUICK_MOVES);
 
   if (tile_set_tmp)
     g_free (tile_set_tmp);
 
-  tile_set_tmp = games_conf_get_string_with_default (NULL, KEY_TILESET, DEFAULT_TILESET);
+  tile_set_tmp = g_settings_get_string (settings, KEY_TILESET);
 
   t_animate = animate;
   t_animate_stagger = animate_stagger;
-  t_grid = grid;
+  t_grid = show_grid;
   t_flip_final = flip_final;
 }
 
@@ -169,7 +148,7 @@ static void
 black_computer_level_select (GtkWidget * widget, gpointer data)
 {
   if ((GPOINTER_TO_INT (data) != t_black_computer_level)
-      && (GTK_TOGGLE_BUTTON (widget)->active)) {
+      && (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))) {
     t_black_computer_level = GPOINTER_TO_INT (data);
     apply_changes ();
   }
@@ -179,7 +158,7 @@ static void
 white_computer_level_select (GtkWidget * widget, gpointer data)
 {
   if ((GPOINTER_TO_INT (data) != t_white_computer_level)
-      && (GTK_TOGGLE_BUTTON (widget)->active)) {
+      && (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))) {
     t_white_computer_level = GPOINTER_TO_INT (data);
     apply_changes ();
   }
@@ -188,14 +167,14 @@ white_computer_level_select (GtkWidget * widget, gpointer data)
 static void
 sound_select (GtkWidget * widget, gpointer data)
 {
-  sound = GTK_TOGGLE_BUTTON (widget)->active;
+  sound = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
   apply_changes ();
 }
 
 static void
 quick_moves_select (GtkWidget * widget, gpointer data)
 {
-  if (GTK_TOGGLE_BUTTON (widget)->active)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     t_quick_moves = 1;
   else
     t_quick_moves = 0;
@@ -205,7 +184,7 @@ quick_moves_select (GtkWidget * widget, gpointer data)
 static void
 flip_final_select (GtkWidget * widget, gpointer data)
 {
-  if (GTK_TOGGLE_BUTTON (widget)->active)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     t_flip_final = 1;
   else
     t_flip_final = 0;
@@ -215,7 +194,7 @@ flip_final_select (GtkWidget * widget, gpointer data)
 static void
 animate_stagger_select (GtkWidget * widget, gpointer data)
 {
-  if (GTK_TOGGLE_BUTTON (widget)->active)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     t_animate_stagger = 1;
   else
     t_animate_stagger = 0;
@@ -225,7 +204,7 @@ animate_stagger_select (GtkWidget * widget, gpointer data)
 static void
 grid_select (GtkWidget * widget, gpointer data)
 {
-  if (GTK_TOGGLE_BUTTON (widget)->active)
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     t_grid = 1;
   else
     t_grid = 0;
@@ -235,7 +214,7 @@ grid_select (GtkWidget * widget, gpointer data)
 static void
 animate_select (GtkWidget * widget, gpointer data)
 {
-  if (GTK_TOGGLE_BUTTON (widget)->active) {
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
     t_animate = GPOINTER_TO_INT (data);
   }
   apply_changes ();
@@ -244,25 +223,25 @@ animate_select (GtkWidget * widget, gpointer data)
 static void
 save_properties (void)
 {
-  games_conf_set_integer (NULL, KEY_BLACK_LEVEL, black_computer_level);
-  games_conf_set_integer (NULL, KEY_WHITE_LEVEL, white_computer_level);
+  g_settings_set_int (settings, KEY_BLACK_LEVEL, black_computer_level);
+  g_settings_set_int (settings, KEY_WHITE_LEVEL, white_computer_level);
 
-  games_conf_set_boolean (NULL, KEY_QUICK_MOVES, t_quick_moves);
+  g_settings_set_boolean (settings, KEY_QUICK_MOVES, t_quick_moves);
 
-  games_conf_set_string (NULL, KEY_TILESET, tile_set_tmp);
+  g_settings_set_string (settings, KEY_TILESET, tile_set_tmp);
 
-  games_conf_set_integer (NULL, KEY_ANIMATE, animate);
+  g_settings_set_int (settings, KEY_ANIMATE, animate);
 
-  games_conf_set_boolean (NULL, KEY_ANIMATE_STAGGER, animate_stagger);
-  games_conf_set_boolean (NULL, KEY_SHOW_GRID, grid);
-  games_conf_set_boolean (NULL, KEY_FLIP_FINAL_RESULTS, flip_final);
-  games_conf_set_boolean (NULL, KEY_SOUND, sound);
+  g_settings_set_boolean (settings, KEY_ANIMATE_STAGGER, animate_stagger);
+  g_settings_set_boolean (settings, KEY_SHOW_GRID, show_grid);
+  g_settings_set_boolean (settings, KEY_FLIP_FINAL_RESULTS, flip_final);
+  g_settings_set_boolean (settings, KEY_SOUND, sound);
 }
 
 static void
 apply_changes (void)
 {
-  guint i, j;
+  guint redraw = 0;
 
   black_computer_level = t_black_computer_level;
   white_computer_level = t_white_computer_level;
@@ -285,34 +264,21 @@ apply_changes (void)
   if (strcmp (tile_set, tile_set_tmp)) {
     g_free (tile_set);
     tile_set = g_strdup (tile_set_tmp);
-    load_pixmaps ();
-    set_bg_color ();
-    for (i = 0; i < 8; i++)
-      for (j = 0; j < 8; j++)
-	if (pixmaps[i][j] >= BLACK_TURN && pixmaps[i][j] <= WHITE_TURN)
-	  gui_draw_pixmap_buffer (pixmaps[i][j], i, j);
-	else
-	  gui_draw_pixmap_buffer (0, i, j);
-    gui_draw_grid ();
+    redraw = 1;
   }
 
   animate = t_animate;
 
-  if (flip_pixmaps_id) {
-    g_source_remove (flip_pixmaps_id);
-    flip_pixmaps_id = 0;
-  }
-
   switch (animate) {
   case 0:
-    flip_pixmaps_id = g_timeout_add (100, flip_pixmaps, NULL);
+    set_animation_speed (100);
     break;
   case 1:
-    flip_pixmaps_id = g_timeout_add (PIXMAP_FLIP_DELAY * 8,
-				     flip_pixmaps, NULL);
+    set_animation_speed (PIXMAP_FLIP_DELAY * 8);
     break;
+  default:
   case 2:
-    flip_pixmaps_id = g_timeout_add (PIXMAP_FLIP_DELAY, flip_pixmaps, NULL);
+    set_animation_speed (PIXMAP_FLIP_DELAY);
     break;
   }
 
@@ -320,9 +286,14 @@ apply_changes (void)
 
   flip_final = t_flip_final;
 
-  if (grid != t_grid) {
-    grid = t_grid;
-    gui_draw_grid ();
+  if (show_grid != t_grid) {
+    show_grid = t_grid;
+    redraw = 1;
+  }
+
+  if (redraw) {
+    load_pixmaps ();
+    gui_draw_board ();
   }
 
   games_sound_enable (sound);
@@ -366,13 +337,12 @@ free_str (GtkWidget * widget, void *data)
 static GtkWidget *
 fill_menu (void)
 {
-  char *dir;
+  const char *dir;
 
   /* FIXME: we need to check that both dname is valid and that
    * games_file_list_new_images returns something. */
 
-  dir = g_strdup (games_runtime_get_directory (
-                    GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY));
+  dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_PIXMAP_DIRECTORY);
 
   if (theme_file_list)
     g_object_unref (theme_file_list);
@@ -381,8 +351,6 @@ fill_menu (void)
 
   games_file_list_transform_basename (theme_file_list);
  
-  g_free (dir);
-
   return games_file_list_create_widget (theme_file_list, tile_set,
 					GAMES_FILE_LIST_REMOVE_EXTENSION |
 					GAMES_FILE_LIST_REPLACE_UNDERSCORES);
@@ -415,13 +383,15 @@ show_properties_dialog (void)
 					 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 					 NULL);
 
-  gtk_dialog_set_has_separator (GTK_DIALOG (propbox), FALSE);
   gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
-  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (propbox)->vbox), 2);
+  gtk_box_set_spacing
+    (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (propbox))), 2);
   gtk_window_set_resizable (GTK_WINDOW (propbox), FALSE);
   notebook = gtk_notebook_new ();
   gtk_container_set_border_width (GTK_CONTAINER (notebook), 5);
-  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (propbox)->vbox), notebook);
+  gtk_container_add
+    (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (propbox))),
+     notebook);
 
   label = gtk_label_new (_("Game"));
 
@@ -433,7 +403,7 @@ show_properties_dialog (void)
   gtk_table_set_col_spacings (GTK_TABLE (table), 18);
   gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
-  vbox2 = gtk_vbox_new (FALSE, 0);
+  vbox2 = gtk_vbox_new (FALSE, 6);
   gtk_box_pack_start (GTK_BOX (vbox), vbox2, FALSE, FALSE, 0);
 
   button = gtk_check_button_new_with_mnemonic (_("_Use quick moves"));
